package com.vctgo.system.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.vctgo.system.domain.SysReGardenBranch;

import java.util.List;

/**
 * 集团幼儿园租户关联Service接口
 *
 * @author wanglonghua
 * @date 2023-10-28
 */
public interface ISysReGardenBranchService
{
    /**
     * 查询集团幼儿园租户关联
     *
     * @param id 集团幼儿园租户关联主键
     * @return 集团幼儿园租户关联
     */
    SysReGardenBranch selectSysReGardenBranchById(Long id);

    /**
     * 查询集团幼儿园租户关联列表-分页
     *
     * @param sysReGardenBranch 集团幼儿园租户关联
     * @return 集团幼儿园租户关联集合
     */
    IPage<SysReGardenBranch> selectSysReGardenBranchPage(SysReGardenBranch sysReGardenBranch);
    /**
     * 查询集团幼儿园租户关联列表
     *
     * @param sysReGardenBranch 集团幼儿园租户关联
     * @return 集团幼儿园租户关联集合
     */
    List<SysReGardenBranch> selectSysReGardenBranchList(SysReGardenBranch sysReGardenBranch);

    /**
     * 新增集团幼儿园租户关联
     *
     * @param sysReGardenBranch 集团幼儿园租户关联
     * @return 结果
     */
    int insertSysReGardenBranch(SysReGardenBranch sysReGardenBranch);

    /**
     * 修改集团幼儿园租户关联
     *
     * @param sysReGardenBranch 集团幼儿园租户关联
     * @return 结果
     */
    int updateSysReGardenBranch(SysReGardenBranch sysReGardenBranch);

    /**
     * 逻辑删除集团幼儿园租户关联
     *
     * @param ids
     * @return 结果
     */
    int logicalDeleteSysReGardenBranchByIds(Long[] ids);

    /**
     * 批量删除集团幼儿园租户关联
     *
     * @param ids 需要删除的集团幼儿园租户关联主键集合
     * @return 结果
     */
    int deleteSysReGardenBranchByIds(Long[] ids);

    /**
     * 删除集团幼儿园租户关联信息
     *
     * @param id 集团幼儿园租户关联主键
     * @return 结果
     */
    int deleteSysReGardenBranchById(Long id);
}
